@@ -1,29 +1,3 @@
-# coding: utf-8
-# /*##########################################################################
-#
-# Copyright (c) 2016-2017 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# ###########################################################################*/
-
-
 __authors__ = ["J. Garriga"]
 __license__ = "MIT"
 __date__ = "29/09/2021"
@@ -492,6 +466,8 @@ def calculate_RSM_histogram(
 
     # Calculate lab frame q vector for each pixel
     k0 = numpy.array([k, 0, 0])  # Lab frame incidetn wavevector
+    twotheta = numpy.radians(twotheta)
+    eta = numpy.radians(eta)
     kh = k * numpy.stack(
         [
             numpy.cos(twotheta),
@@ -519,7 +495,7 @@ def calculate_RSM_histogram(
 
     # Make histogram ranges
     q_mean = numpy.mean(q, axis=1)
-    diffry_mean = (numpy.mean(diffry_values) - diffry_center) * numpy.pi / 180
+    diffry_mean = numpy.radians(numpy.mean(diffry_values) - diffry_center)
     q_mean = numpy.stack(
         [
             q_mean[0] * numpy.cos(diffry_mean) - q_mean[2] * numpy.sin(diffry_mean),
@@ -548,7 +524,7 @@ def calculate_RSM_histogram(
     # Loop through images
     for i, image in enumerate(loop):
         # read angle
-        diffry = (diffry_values[i] - diffry_center) * numpy.pi / 180
+        diffry = numpy.radians(diffry_values[i] - diffry_center)
         # rotate q back to zero-motor frame
         q_rot = numpy.stack(
             [
